[PATCH] sound: soc: atmel: Don't unconditionally reset SSC on stream startup

Peter Meerwald pmeerw at pmeerw.net
Wed Aug 10 03:14:22 PDT 2016


From: Christoph Huber <c.huber at bct-electronic.com>

commit cbaadf0f90d6 (ASoC: atmel_ssc_dai: refactor the startup and shutdown)
refactored code such that the SSC is reset on every startup;
this breaks duplex audio (e.g. first start audio playback, then start record,
causing the playback to stop/hang)

Signed-off-by: Christoph Huber <c.huber at bct-electronic.com>
Signed-off-by: Peter Meerwald-Stadler <p.meerwald at bct-electronic.com>
Cc: Songjun Wu <songjun.wu at microchip.com>
Cc: Nicolas Ferre <nicolas.ferre at atmel.com>
---
 sound/soc/atmel/atmel_ssc_dai.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/sound/soc/atmel/atmel_ssc_dai.c b/sound/soc/atmel/atmel_ssc_dai.c
index 841d059..b3e9f0c 100644
--- a/sound/soc/atmel/atmel_ssc_dai.c
+++ b/sound/soc/atmel/atmel_ssc_dai.c
@@ -298,8 +298,9 @@ static int atmel_ssc_startup(struct snd_pcm_substream *substream,
 	clk_enable(ssc_p->ssc->clk);
 	ssc_p->mck_rate = clk_get_rate(ssc_p->ssc->clk);
 
-	/* Reset the SSC to keep it at a clean status */
-	ssc_writel(ssc_p->ssc->regs, CR, SSC_BIT(CR_SWRST));
+	/* Reset the SSC if it is not initialized to keep it at a clean status */
+	if(!ssc_p->initialized)
+		ssc_writel(ssc_p->ssc->regs, CR, SSC_BIT(CR_SWRST));
 
 	if (substream->stream == SNDRV_PCM_STREAM_PLAYBACK) {
 		dir = 0;
-- 
2.1.4




More information about the linux-arm-kernel mailing list